@@ -133,9 +133,10 @@ class notion_connector:
 		data = {'properties': {}}
 		i = False
 		for i in properties.items():
-			if self.updateProperties(i[1]) == None:
-				continue
 			data['properties'][i[0]] = self.updateProperties(i[1])
+			if data['properties'][i[0]] == None:
+				del data['properties'][i[0]]
+				continue
 			i = True
 		if i == False:
 			return
